"""
Python RPC Client for Discord
-----------------------------
By: qwertyquerty and LewdNeko
"""

from .client import Client
from .presence import Presence
from .exceptions import *

__title__ = 'pypresence'
__author__ = 'qwertyquerty'
__copyright__ = 'Copyright 2018 qwertyquerty'
__license__ = 'MIT'
__version__ = '1.0.9'
