from setuptools import setup

setup(name='pypresence',
      author='qwertyquerty',
      url='https://github.com/qwertyquerty/pypresence',
      version='2.1.0',
      packages=['pypresence'],
      license='MIT',
      description='Discord RPC client written in python',
	  long_description="A Discord RPC library in python! Wow! Looks like you've come to the right place. Just looking to do Rich Presence? We Got you covered."
)
